/* This file is part of the YAZ toolkit.
 * Copyright (C) Index Data.
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Index Data nor the names of its contributors
 *       may be used to endorse or promote products derived from this
 *       software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * \file tcpip.h
 * \brief Header for TCP/IP + SSL COMSTACK.
 */

#ifndef TCPIP_H
#define TCPIP_H

#include <yaz/comstack.h>

YAZ_BEGIN_CDECL

YAZ_EXPORT COMSTACK tcpip_type(int s, int flags, int protocol, void *vp);
YAZ_EXPORT COMSTACK ssl_type(int s, int flags, int protocol, void *vp);
YAZ_EXPORT COMSTACK yaz_tcpip_create(int s, int flags, int protocol,
                                     const char *connect_host);
YAZ_EXPORT COMSTACK yaz_tcpip_create2(int s, int flags, int protocol,
                                      const char *connect_host,
                                      const char *bind_host);
YAZ_EXPORT COMSTACK yaz_tcpip_create3(int s, int flags, int protocol,
                                      const char *connect_host,
                                      const char *connect_auth,
                                      const char *bind_host);
YAZ_EXPORT COMSTACK yaz_ssl_create(int s, int flags, int protocol,
                                   const char *connect_host,
                                   const char *connect_auth,
                                   const char *bind_host);
YAZ_END_CDECL

#endif
/*
 * Local variables:
 * c-basic-offset: 4
 * c-file-style: "Stroustrup"
 * indent-tabs-mode: nil
 * End:
 * vim: shiftwidth=4 tabstop=8 expandtab
 */

